@@ -53,7 +53,10 @@ class urls :
     def analysis_capital_flow(self, stock, show_hist):
         return f'{self.base_securities_url}/wlas/capitalflow/ticker?tickerId={stock}&showHis={show_hist}'
 
-    def bars(self, stock):
+    def bars(self, stock, interval='d1', count=800):
+        #new
+        return f'{self.base_fintech_gw_url}/quote/charts/query?tickerIds={stock}&type={interval}&count={count}'
+        #old
         return f'{self.base_quote_url}/quote/tickerChartDatas/v5/{stock}'
 
     def bars_crypto(self, stock):
@@ -175,8 +178,8 @@ class urls :
     def rankings(self):
         return f'{self.base_securities_url}/securities/market/v5/6/portal'
 
-    def refresh_login(self):
-        return f'{self.base_user_url}/passport/refreshToken?refreshToken='
+    def refresh_login(self, refresh_token):
+        return f'{self.base_user_url}/passport/refreshToken?refreshToken={refresh_token}'
 
     def remove_alert(self):
         return f'{self.base_userbroker_url}/user/warning/v2/manage/overlap'
@@ -184,6 +187,9 @@ class urls :
     def replace_option_orders(self, account_id):
         return f'{self.base_trade_url}/v2/option/replaceOrder/{account_id}'
 
+    def stock_detail(self, stock) :
+        return f'{self.base_fintech_gw_url}/stock/tickerRealTime/getQuote?tickerId={stock}&includeSecu=1&includeQuote=1&more=1'
+
     def stock_id(self, stock, region_code):
         return f'{self.base_options_gw_url}/search/pc/tickers?keyword={stock}&pageIndex=1&pageSize=20&regionId={region_code}'
 
@@ -213,3 +219,6 @@ class urls :
 
     def calendar_events(self, event, region_code, start_date, page=1, num=50):
         return f'{self.base_fintech_gw_url}/bgw/explore/calendar/{event}?regionId={region_code}&pageIndex={page}&pageSize={num}&startDate={start_date}'
+
+    def get_all_tickers(self, region_code, user_region_code) :
+        return f'{self.base_securitiesfintech_url}/securities/market/v5/card/stockActivityPc.advanced/list?regionId={region_code}&userRegionId={user_region_code}&hasNum=0&pageSize=9999'
