@@ -18,7 +18,7 @@ from pytz import timezone
 from . import endpoints
 
 
-class webull:
+class webull :
 
     def __init__(self) :
         self._session = requests.session()
@@ -257,12 +257,13 @@ class webull:
         headers = self.build_req_headers()
         data = {'refreshToken': self._refresh_token}
 
-        response = requests.post(self._urls.refresh_login() + self._refresh_token, json=data, headers=headers, timeout=self.timeout)
+        response = requests.post(self._urls.refresh_login(self._refresh_token), json=data, headers=headers, timeout=self.timeout)
         result = response.json()
         if 'accessToken' in result and result['accessToken'] != '' and result['refreshToken'] != '' and result['tokenExpireTime'] != '':
             self._access_token = result['accessToken']
             self._refresh_token = result['refreshToken']
             self._token_expire = result['tokenExpireTime']
+            self._account_id = self.get_account_id()
             if save_token:
                 result['uuid'] = self._uuid
                 self._save_token(result, token_path)
@@ -379,11 +380,11 @@ class webull:
         else:
             return False
 
+    '''
+    Lookup ticker_id
+    Ticker issue, will attempt to find an exact match, if none is found, match the first one
+    '''
     def get_ticker(self, stock=''):
-        '''
-        Lookup ticker_id
-        Ticker issue, will attempt to find an exact match, if none is found, match the first one
-        '''
         headers = self.build_req_headers()
         ticker_id = 0
         if stock and isinstance(stock, str):
@@ -405,6 +406,39 @@ class webull:
             raise ValueError('Stock symbol is required')
         return ticker_id
 
+    '''
+    Get stock public info
+    get price quote
+    tId: ticker ID str
+    '''
+    def get_ticker_info(self, stock=None, tId=None) :
+        headers = self.build_req_headers()
+        if not stock and not tId:
+            raise ValueError('Must provide a stock symbol or a stock id')
+
+        if stock :
+            try:
+                tId = str(self.get_ticker(stock))
+            except ValueError as _e:
+                raise ValueError("Could not find ticker for stock {}".format(stock))
+        response = requests.get(self._urls.stock_detail(tId), headers=headers, timeout=self.timeout)
+        result = response.json()
+        return result
+
+    '''
+    Get all tickers from a region
+    region id: https://github.com/tedchou12/webull/wiki/What-is-the-region_id%3F
+    '''
+    def get_all_tickers(self, region_code=None) :
+        headers = self.build_req_headers()
+
+        if not region_code :
+            region_code = self._region_code
+
+        response = requests.get(self._urls.get_all_tickers(region_code, region_code), headers=headers, timeout=self.timeout)
+        result = response.json()
+        return result
+
     '''
     Actions related to stock
     '''
@@ -1112,10 +1146,10 @@ class webull:
         else:
             raise ValueError('Must provide a stock symbol or a stock id')
 
-        params = {'type': interval, 'count': count, 'extendTrading': extendTrading, 'timestamp': timeStamp}
+        # params = {'type': interval, 'count': count, 'extendTrading': extendTrading, 'timestamp': timeStamp}
         df = DataFrame(columns=['open', 'high', 'low', 'close', 'volume', 'vwap'])
         df.index.name = 'timestamp'
-        response = requests.get(self._urls.bars(tId), params=params, headers=headers, timeout=self.timeout)
+        response = requests.get(self._urls.bars(tId, interval, count), headers=headers, timeout=self.timeout)
         result = response.json()
         time_zone = timezone(result[0]['timeZone'])
         for row in result[0]['data']:
@@ -1207,7 +1241,12 @@ class webull:
             df.loc[to_datetime(datetime.fromtimestamp(int(row[0])).astimezone(time_zone))] = data
         return df.iloc[::-1]
 
-    def get_calendar(self,stock=None, tId=None):
+    def get_chart_data(self, stock=None, tId=None, ma=5) :
+        bars = self.get_bars(stock=stock, tId=tId, interval='d1', count=800)
+        ma_data = bars['close'].rolling(ma).mean()
+        return ma_data
+
+    def get_calendar(self, stock=None, tId=None):
         '''
         There doesn't seem to be a way to get the times the market is open outside of the charts.
         So, best way to tell if the market is open is to pass in a popular stock like AAPL then
